(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     61460,       2038]*)
(*NotebookOutlinePosition[     67812,       2201]*)
(*  CellTagsIndexPosition[     66620,       2170]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Chapter 1", "Subtitle"],

Cell[CellGroupData[{

Cell["Description of Diffusion", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Description of Normal Diffusion"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Plan of Action"
}], "Subsection"],

Cell["\<\
In history there are several kinds to describe diffusion. In the following \
only some of them shall be introduced to choose more detailed, before \
anomalous diffusion is described.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Fick's Diffusion"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Fick's Laws"
}], "Subsubsection"],

Cell["Additional to the continuity equation", "Text"],

Cell[BoxData[
    \(\(\[PartialD]\_t \[Rho][x, t] + \[PartialD]\_x j[x, t] = 0\ , \)\)], 
  "NumberedEquation",
  CellTags->"Kontinuit\[ADoubleDot]tsgleichung"],

Cell[TextData[{
  "with mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho][x, t]\)]],
  " and stream density ",
  Cell[BoxData[
      \(TraditionalForm\`j[x, t]\)]],
  " in the coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", a so-called constitutive or essential equation is needed, which \
establishes a further connection between stream density and mass density."
}], "Text"],

Cell[TextData[{
  "Due to Fick the first of Fick's laws (see ",
  ButtonBox["[Metz1996]",
    ButtonData:>{"Literatur.nb", "[Metz1996]"},
    ButtonStyle->"Hyperlink"],
  ", equation (6.2), page 74) yields the following relation:"
}], "Text"],

Cell[BoxData[
    \(j[x, t] = \(-\[Lambda]\) \(\[PartialD]\_x \[Rho][x, t]\ .\)\)], 
  "NumberedEquation",
  CellTags->"1.Ficksches Gesetz"],

Cell[TextData[{
  "The diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", being contained in Fick's first law (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "1.Ficksches Gesetz"],
  "), is a material quantity, which can change spatially by the dimensions of \
the experiment and also even temporally by chemical reactions within the \
same. These effects shall not be the focal point of this elaboration, \
therefore in the following the diffusion parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " almost everywhere is a real material constant in space and time."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "By substitution of Fick's first law (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "1.Ficksches Gesetz"],
  ") into the continuity equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Kontinuit\[ADoubleDot]tsgleichung"],
  ") Fick's second law is following, which already is considered to be a \
diffusion equation, here being completed by an arbitrary stearing quantity ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] - 
        \[Lambda] \[PartialD]\_\(x\ x\)\[Rho][x, t] = \(s[x, t]\ .\)\)], 
  "NumberedEquation",
  CellTags->"2.Ficksches Gesetz"],

Cell[TextData[{
  "If external influences are absent (stearing quantity ",
  Cell[BoxData[
      \(TraditionalForm\`s[x, t] \[Congruent] 0\)]],
  "), then also the continuity equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Kontinuit\[ADoubleDot]tsgleichung"],
  ") owns neither sources nor hollows, thus the spatial integral of the mass \
density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho][x, t]\)]],
  " represents a temporal conservation quantity. Therefore in theory the \
density usually is normalized. Equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") also occurs in connection with Fourier's theory of heat conduction, \
where in this case the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is replaced by the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Propagator of Fick's Diffusion"
}], "Subsubsection"],

Cell[TextData[{
  "The propagator of Fick's diffusion equation (calculation see chapter 3 of \
this elaboration) yields from Dirac's delta function (",
  ButtonBox["[Dir1927]",
    ButtonData:>{"Literatur.nb", "[Dir1927]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]2, pages 624-627) being the initial value problem:"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x, t] = 
      \(\((Exp[\(-\(x\^2\/\(4\ \[Lambda]\ t\)\)\)]
              \/\@\(4  \[Pi]\ \[Lambda]\ t\))\)\ .\)\)], "NumberedEquation",
  CellTags->"Fickscher Diffusionspropagator"],

Cell[TextData[{
  "The Fourier convolution of the factual initial distribution with the \
propagator yields the general solution of the homogeneous part of equation (",
  
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Normal Distribution and Einstein's Relation"
}], "Subsubsection"],

Cell[TextData[{
  "The propagator of Fick's diffusion equation is a Gaussian bell-curve, \
which also in statistical theory owns a special importance (",
  ButtonBox["[Acz1961]",
    ButtonData:>{"Literatur.nb", "[Acz1961]"},
    ButtonStyle->"Hyperlink"],
  ", section 2.3.5., pages 94-97). In 1809 it has been given by Gauss in \
general with the so-called variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  ", the mean sum of scatter squares, and in this case it is called ",
  StyleBox["normal distribution",
    FontSlant->"Italic"],
  " (",
  ButtonBox["[BrS1987]",
    ButtonData:>{"Literatur.nb", "[BrS1987]"},
    ButtonStyle->"Hyperlink"],
  ", section 5.1.2.2.2, page 664):"
}], "Text"],

Cell[BoxData[
    \(f[x] = 
      \(\((Exp[\(-\(\((x - \[Mu])\)\^2\/\(2  \[Sigma]\^2\)\)\)]
              \/\@\(2  \[Pi]\ \[Sigma]\^2\))\)\ .\)\)], "NumberedEquation",
  CellTags->"Normalverteilung"],

Cell[TextData[{
  "From the equations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fickscher Diffusionspropagator"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Normalverteilung"],
  ") by coefficient comparison directly results the variance of Fick's \
diffusion propagator, namely ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = 2  \[Lambda]\ t\)]],
  ", which is designated as Einstein's relation."
}], "Text"],

Cell["\<\
In general the variance is calculated from the first three momenta of a \
distribution (see appendix A of this elaboration).\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Normal Diffusion due to Cattaneo"
}], "Subsection",
  PageBreakAbove->True],

Cell[TextData[{
  "In the year 1948 C. Cattaneo in Rome published a paper ",
  ButtonBox["[Cat1948]",
    ButtonData:>{"Literatur.nb", "[Cat1948]"},
    ButtonStyle->"Hyperlink"],
  ", wherein a diffusion equation is introduced, being motivated by molecular \
kinetics, which is the following (",
  ButtonBox["[Cat1948]",
    ButtonData:>{"Literatur.nb", "[Cat1948]"},
    ButtonStyle->"Hyperlink"],
  ", equation (22), page 94):"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] + 
        \[Tau]\ \[PartialD]\_\(t\ t\)\[Rho][x, t] - 
        \[Lambda] \[PartialD]\_\(x\ x\)\[Rho][x, t] = \(s[x, t]\ .\)\)], 
  "NumberedEquation",
  CellTags->"Cattaneo-Gleichung"],

Cell[TextData[{
  "Here a specific time ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " occurs, which considers the finiteness of the characteristic diffusion \
velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ". This connection is indicated by Cattaneo (",
  ButtonBox["[Cat1948]",
    ButtonData:>{"Literatur.nb", "[Cat1948]"},
    ButtonStyle->"Hyperlink"],
  ", equation (23), page 94) and explicitly repeated by T. F. Nonnenmacher (",
  
  ButtonBox["[Non1980]",
    ButtonData:>{"Literatur.nb", "[Non1980]"},
    ButtonStyle->"Hyperlink"],
  ", text after formula (4), page 363):"
}], "Text"],

Cell[BoxData[
    \(\[Lambda] = v\^2\ \(\[Tau]\ .\)\)], "NumberedEquation",
  CellTags->"Diffusionskonstante"],

Cell[TextData[{
  "A connection to Boltzmann's impact dynamics is given in these \
elaborations, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " is proportional to the finite time between two impacts."
}], "Text"],

Cell[TextData[{
  "If a limit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] \[Rule] 0\)]],
  " is calculated in such a way, that the diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " remains constantly during this, then the characteristic velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " becomes infinitely large, and Fick's diffusion equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") is regained."
}], "Text"],

Cell[TextData[{
  "The equation by Cattaneo is of hyperbolic type and quite difficult to be \
solved. Not yet the complete momenta of the propagators are found in \
literature (",
  ButtonBox["[dJag1980]",
    ButtonData:>{"Literatur.nb", "[dJag1980]"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["[CM1997]",
    ButtonData:>{"Literatur.nb", "[CM1997]"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["[MN1998]",
    ButtonData:>{"Literatur.nb", "[MN1998]"},
    ButtonStyle->"Hyperlink"],
  "). The variance of the static solution propagator (with start velocity \
zero) here is given without derivation:"
}], "Text"],

Cell[BoxData[
    \(\[Sigma]\^2 = 
      2  \[Lambda]\ \((t - \[Tau])\) + 
        2  \[Lambda]\ \[Tau]\ Exp[\(-t\)/\[Tau]]\)], "NumberedEquation",
  CellTags->"Varianz der Cattaneo-Gleichung"],

Cell[TextData[{
  "(calculation procedure: see chapter 2). This means due to the variance \
theorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  "), that the solution of the static Cattaneo propagator is given as a \
Fourier convolution of two functions. For short times the variance starts by \
the variance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Wellen-Varianz"],
  ") of a wave equation, which during this elaboration is named as wave \
variance: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = \(\[Lambda]\/\[Tau]\) t\^2\)]],
  ", and for long times ",
  Cell[BoxData[
      \(TraditionalForm\`t >> \[Tau]\)]],
  " it passes over to a time shifted Fickian diffusion variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = 2  \[Lambda]\ t\)]],
  "."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "A comparison of the Cattaneo variance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianz der Cattaneo-Gleichung"],
  "), starting as wave variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2 = \(\[Lambda]\/\[Tau]\) t\^2\)]],
  ", to the usual wave variance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Wellen-Varianz"],
  ") yields an interpretation of the characteristic velocity in the diffusion \
parameter (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") as wave expansion velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "."
}], "Text"],

Cell[TextData[{
  "From the mathematical point of view the Cattaneo equation does not \
distinguish from the so-called telegraph equation (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]204, equations (8) and (9), page 480), which can be derived in \
electrodynamics to describe a damped electromagnetic wave. However, the \
phenomenons ",
  StyleBox["damped wave",
    FontSlant->"Italic"],
  " and ",
  StyleBox["diffusion",
    FontSlant->"Italic"],
  " eventually are not the same. Therefore also further diffusion models can \
be searched for."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Normal Diffusion due to Diffusion Principle"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Verbal Formulation of Diffusion Principle"
}], "Subsubsection"],

Cell[TextData[{
  "Analogously to Huygens' principle for wave expansion (",
  ButtonBox["[BeS1945]",
    ButtonData:>{"Literatur.nb", "[BeS1945]"},
    ButtonStyle->"Hyperlink"],
  ", ",
  StyleBox["I",
    FontWeight->"Bold"],
  ", \[Section]76, pages 362-369) from the year 1678, also a diffusion \
principle can be described, which could be the following:"
}], "Text"],

Cell["\<\
Each point of a matter distribution is starting point of a new elementary \
matter redistribution. The elementary matter redistribution takes place in \
such a way, that the space being available is used for it. The superposition \
of all new elementary matter redistributions yields the new matter \
distribution.\
\>", "Text",
  TextAlignment->Left,
  FontSlant->"Italic"],

Cell["\<\
The essential difference to the principle of wave expansion consists in the \
fact, that no envelope of the new elementary processes takes place.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Superposition Possibility"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The same of diffusion principle and of Huygens' principle for wave \
expansion is, that the separation of the dynamics into elementary, singular \
processes is possible, which themselves are very simple. Therefore global\
\[VeryThinSpace] diffusion is described by local conflusion (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") (Latin confluere: flow together)."
}], "Text"],

Cell[TextData[{
  "For mathematical description of superposable (being able to be \
superimposed) phenomenons serve linear equations (",
  ButtonBox["[Stoe1998]",
    ButtonData:>{"Literatur.nb", "[Stoe1998]"},
    ButtonStyle->"Hyperlink"],
  ", 7.1.1.7, page 201). The superposition possibility of diffusive processes \
in the following is estimated to be given, wherefore furtheron only linear \
equations are discussed. Also the equations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") are linear and therefore allow the additional consideration of stearing \
quantities. In literature also non-linear diffusion equations occur (for \
example ",
  ButtonBox["[HD1998]",
    ButtonData:>{"Literatur.nb", "[HD1998]"},
    ButtonStyle->"Hyperlink"],
  "), which are not followed up as part of this elaboration."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Difference Equation"
}], "Subsubsection"],

Cell[TextData[{
  "The given diffusion principle in the easiest case can be modeled as linear \
difference equation in a single space dimension, which can be generalized to \
problems of radial symmetry. With the density distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho][x, t]\)]],
  " and a characteristic velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ", being introduced to conserve all physical units, and the time difference \
",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t\)]],
  ", this approach yields the following equation for an elementary process:"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x - v\ \[CapitalDelta]t, t - \[CapitalDelta]t]\/2 + 
        \[Rho][x + v\ \[CapitalDelta]t, t - \[CapitalDelta]t]\/2 = 
      \(\[Rho][x, t]\ .\)\)], "NumberedEquation",
  CellTags->"Differenzengleichung"],

Cell[TextData[{
  "During diffusion the movement of a singular particle almost always takes \
place in a zigzag course, thus the maximum velocity of diffusion within the \
context of this model is given by the global sound velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " (wave expansion velocity) of the system. Both effects (diffusion and \
wave) can be understood as caused by singular impacts."
}], "Text"],

Cell[TextData[{
  "If the atomic character of matter is to be stressed, then one must \
consider, that between two singular impacts really a finite duration time, \
namely ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t > 0\)]],
  ", takes place. For this kind of consideration and also for computer \
simulations, equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") is a possible access to the description of diffusion events, which of \
course can be improved."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Solution to the Difference Equation"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The given difference equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") in the sense of the scanning theorem in telecommunications technology (",
  
  ButtonBox["[Mar1986]",
    ButtonData:>{"Literatur.nb", "[Mar1986]"},
    ButtonStyle->"Hyperlink"],
  ", chapter 6, pages 127-131) owns a definite solution for an initial value \
problem, which starts by a standardized total distribution at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[Rho][x, t]\), "=", 
      RowBox[{
        RowBox[{
        \(1\/\(2  v\ \[CapitalDelta]t\)\), \(1\/2\^\(t\/\[CapitalDelta]t\)\), 
          
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {\(t\/\[CapitalDelta]t\)},
                {\(\(x + v\ t\)\/\(2  v\ \[CapitalDelta]t\)\)}
                }], "\[NegativeThinSpace]", ")"}]}], "=", 
        \(\((\(1\/\(2  v\ \[CapitalDelta]t\)\) 
              \(1\/2\^\(t\/\[CapitalDelta]t\)\) 
              \(\((t\/\[CapitalDelta]t)\)!
                  \)\/\(\(\((\(x + v\ t\)\/\(2  v\ \[CapitalDelta]t\))\)!\) 
                  \(\((\(x - v\ t\)\/\(2  v\ \[CapitalDelta]t\))\)!\)\))\).
          \)}]}]], "NumberedEquation",
  CellTags->"Binomialverteilung"],

Cell[TextData[{
  "The verification of the binomial distribution (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") as solution to the diffusion equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") can be done by elementary calculation. The norm constant furthermore has \
been set to ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\(2  v\ \[CapitalDelta]t\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The variance of the symmetrical binomial distribution (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") is known, if the coefficients are not weighted: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Sigma]\^2\), "[", 
            RowBox[{\(2\^\(\(-n\)\ \)\), 
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"n"},
                    {\(k - n\/2\)}
                    }], "\[NegativeThinSpace]", ")"}]}], "]"}], " ", "=", 
          \(n\/4\)}], TraditionalForm]]],
  ". The use of the substitution ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] 2  v\ \[CapitalDelta]t\ k\)]],
  " for the variance calculation of the standardized binomial distribution (",
  
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") yields:"
}], "Text"],

Cell[BoxData[
    \(\(\[Sigma]\^2 = 
      \(\(1\/\(2  v\ \[CapitalDelta]t\)\) \(\((2  v\ \[CapitalDelta]t)\)\^3\) 
          t\/\(4  \[CapitalDelta]t\) = 
        \(\[CapitalDelta]t\ v\^2\ t = 2  \[Lambda]\ t\)\)\ , \)\)], 
  "NumberedEquation",
  CellTags->"Varianz der Binomialverteilung"],

Cell[TextData[{
  "where the last mentioned identity follows with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 2  \[Tau]\)]],
  " in relation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Transition to a Differential Equation"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "If the difference equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") is interpreted in such a way, that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t\)]],
  " shall be the variable of a Taylor's series (thus the solution function be \
steady and differentiable), then the Taylor's series of this difference \
equation yields the following differential equation with error order ",
  Cell[BoxData[
      \(TraditionalForm\`O[\[CapitalDelta]t\^2]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\_t \[Rho][x, t] - 
        \[CapitalDelta]t\/2\ \[PartialD]\_\(t\ t\)\[Rho][x, t] - 
        \(\(v\^2\ \[CapitalDelta]t\)\/2\) \[PartialD]\_\(x\ x\)\[Rho][x, t] = 
      \(s[x, t]\ .\)\)], "NumberedEquation",
  CellTags->"modifizierte Cattaneo-Gleichung"],

Cell[TextData[{
  "This is an elliptic modification of Cattaneo's equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  "), where the shape of the diffusion coefficient (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") is confirmed for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 2  \[Tau]\)]],
  ". Also the modified Cattaneo equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") can only be solved heavily. Here, even the variance calculation of the \
static solution propagator hides severe difficulties."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Further Proceeding"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Limit Calculation to Fick's Diffusion Equations"
}], "Subsubsection"],

Cell[TextData[{
  "The limit calculation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] \[Rule] 0\)]],
  " with conversation of the diffusion coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " in equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ") changes Cattaneo's equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") into Fick's diffusion equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  "). The same result is received by the limit calculation ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t \[Rule] 0\)]],
  ", if the expansion velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " in the modified Cattaneo equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") runs to infinity in such a way, that the diffusion parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " remains constant due to equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionskonstante"],
  ")."
}], "Text"],

Cell[TextData[{
  "By this limit calculation the solution (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") turns to the propagator (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fickscher Diffusionspropagator"],
  ") of Fick's diffusion:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(P[x, t]\), "=", 
      RowBox[{
        RowBox[{
          FractionBox[
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(t\/\[CapitalDelta]t\)},
                  {\(\(x + v\ t\)\/\(2\ v\ \[CapitalDelta]t\)\)}
                  }], "\[NegativeThinSpace]", ")"}], 
            \(2\ v\ \[CapitalDelta]t\ 2\^\(t\/\[CapitalDelta]t\)\)], 
          "\[TildeTilde]", 
          \(Exp[\(-\(x\^2\/\(2\ v\^2\ \[CapitalDelta]t\ t\)\)\)]\/\(2\ v\ 
                \[CapitalDelta]t \@\( \[Pi]\/2\ t\/\[CapitalDelta]t\)\)\)}], 
        "=", \(\((
            Exp[\(-\(x\^2\/\(4  \[Lambda]\ t\)\)\)]
                \/\@\(4\ \[Pi]\ \[Lambda]\ t\))\)\ .\)}]}]], 
  "NumberedEquation",
  CellTags->"Binomialer Grenz\[UDoubleDot]bergang"],

Cell[TextData[{
  "In this connection the author thanks Mr. Professor Dr. P. Chvosta (Prague) \
for a detailed discussion about the simultaneous limit calculation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialer Grenz\[UDoubleDot]bergang"],
  ")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Hypothesis on Variance"
}], "Subsubsection",
  PageBreakAbove->True],

Cell[TextData[{
  "The variance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianz der Binomialverteilung"],
  ") of the binomial distribution (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Binomialverteilung"],
  ") is equal to the variance of Fick's diffusion propagator (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Fickscher Diffusionspropagator"],
  "), namely ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Sigma]\^2 = \(\[CapitalDelta]t\ v\^2\ t = 2  \[Lambda]\ t\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Therefore the normal diffusion owns independently of the question about \
the finiteness or boundlessness of the characteristic wave expansion velovity \
",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " a uniform variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  ", which increases proportionally to the measuring time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". In the elaborations of A. Einstein, who claimed the finiteness of wave \
expansion velocity to be essential, thus no internal contradiction is found, \
since Einstein's relation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianz der Binomialverteilung"],
  ") is valid not only for Fick's diffusion propagator, but also for the \
discrete binomial distribution. A propagator starts at time ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] 0\)]],
  " as Dirac's delta function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta][x]\)]],
  ", the variance of which is zero. The variance does not tell anything about \
the precise shape of a distribution function."
}], "Text"],

Cell[TextData[{
  "The hypothesis suggests itself, that the elliptic modification of \
Cattaneo's equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  ") compared to the parabolic Fickian diffusion equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") or the difference equation of the binomial distribution (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  ") does not own a fundamentally different variance. Due to Einstein's \
relation all three equation types describe the ",
  StyleBox["normal diffusion",
    FontSlant->"Italic"],
  " as part of a corresponding model. The hyperbolic Cattaneo equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") for long times also owns the variance of normal diffusion."
}], "Text"],

Cell[TextData[{
  "The naming of partial linear differential equations of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^nd\)]],
  " order after conic sections is related to the characteristics method (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", \[Section]146, pages 282-286), which shall not be applied as part of \
this elaboration."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Classification of Diffusion"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Comparing Measured Data with Theoretical Propagators"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Problem"
}], "Subsubsection"],

Cell["\<\
A theoretical propagator always starts with a Dirac's delta function as \
initial value problem. However, this initial value problem cannot strictly be \
realized in any experiment.\
\>", "Text"],

Cell["\<\
Rather the general solution of a partial linear differential equation (at \
least for constant coefficients) arises as Fourier convolution of the time \
dependent propagator with the time independent initial distribution.\
\>", "Text"],

Cell["\<\
These considerations question first the classification of diffusive processes \
via Einstein's relation, because not the propagator is measured itself, but a \
Fourier convolution with this propagator only.\
\>", "Text"],

Cell["\<\
Therefore a direct comparison of measured data to theoretically calculated \
propagators is not easy.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Variance Theorem"
}], "Subsubsection"],

Cell[TextData[{
  "In this connection, the variance theorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") is of special importance (proof see appendix A of this elaboration), \
which enables a universal comparison of theoretical propagators of linear \
equations to measured data. It describes the variance of a Fourier \
convolution as sum of the variances of their convolution components:"
}], "Text"],

Cell[BoxData[
    \(\(\[Sigma]\^2\)[f[x]*g[x]] = 
      \(\(\[Sigma]\^2\)[
          \[Integral]\_\(-\[Infinity]\)\%\[Infinity] f[x - y] g[y] 
              \[DifferentialD]y] = 
        \(\[Sigma]\^2\)[f[x]] + \(\(\[Sigma]\^2\)[g[x]]\ .\)\)\)], 
  "NumberedEquation",
  CellFrame->True,
  CellTags->"Varianztheorem"],

Cell[TextData[{
  "The system, being described via a linear equation, is described by a \
Fourier convolution of the time dependent propagator ",
  Cell[BoxData[
      \(TraditionalForm\`p[x, t]\)]],
  " and the time independent initial distribution ",
  Cell[BoxData[
      \(TraditionalForm\`f[x, t\_0]\)]],
  ". The Fourier convolution with a Dirac's delta function (see chapter 2 of \
this elaboration) always yields the other convoluted function:"
}], "Text"],

Cell[BoxData[
    \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \[Delta][x - y] g[y] 
          \[DifferentialD]y = \(g[x]\ .\)\)], "NumberedEquation",
  CellTags->"Delta-Faltung"],

Cell[TextData[{
  "With both insights (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Delta-Faltung"],
  ") the variance of the propagator follows via a corresponding variance \
balance of measured data:"
}], "Text",
  PageBreakAbove->True],

Cell[BoxData[
    \(\(\[Sigma]\^2\)[f[x, t\_0]*p[x, t - t\_0]] - 
        \(\[Sigma]\^2\)[f[x, t\_0]*\[Delta][x]] = 
      \(\(\[Sigma]\^2\)[p[x, t - t\_0]]\ .\)\)], "NumberedEquation",
  CellTags->"Varianzabgleich"],

Cell["\<\
Thus the comparison of theory to measurement is quite easy via the \
variance.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Importance of the Variance Theorem"
}], "Subsubsection"],

Cell["\<\
The variance of measured data always can be calculated. The variance of the \
theoretical function can be calculated only, if the function values of the \
spatial interval can be set to zero from a clearly definable position on, \
being outside of the measurement area.\
\>", "Text"],

Cell["\<\
A theoretical function describes measured data particularly well, if the \
numerical value of the theoretical function outside of the measuring area is \
as good as zero. In this case, the momentum integrals and also the variance \
usually still without problems can be calculated with infinite integration \
limits.\
\>", "Text"],

Cell[TextData[{
  "The variance theorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") gives a universal access to enable comparison of the dynamics of complex \
(complicated) linear systems to corresponding measured data. Especially the \
falsification of a theory is possible via the variance balance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianzabgleich"],
  ")."
}], "Text"],

Cell["\<\
In this way, many different theories can be compared to real measured data \
rapidly and reliably.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Classification of Transport Processes via Variance"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Confirmation of Einstein's Relation"
}], "Subsubsection"],

Cell[TextData[{
  "In case of normal diffusion, the variance balance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianzabgleich"],
  ") leads to a confirmation of Einstein's relation also for measured data, \
which does not start with variance zero. Here, the question on the finiteness \
of the characteristic velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " is not to be discussed completely!"
}], "Text"],

Cell[TextData[{
  "Thus for this elaboration, there is sufficiency to model the variants to \
Fick's diffusion law (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") in such a way, that they both can be solved as easy as possible and \
satisfy an expanded Einstein's relation, which also describes ",
  StyleBox["anomalous diffusion",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "Mainly these variants are given in shape of ",
  StyleBox["fractional differential equations",
    FontSlant->"Italic"],
  ". Often their solution propagators are ",
  StyleBox["Fox's H-functions",
    FontSlant->"Italic"],
  " (see chapter 2 of this elaboration) only, which are quite pleasant from \
the analytical and numerical point of view."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Variance of the Static Wave Propagator"
}], "Subsubsection",
  PageBreakAbove->True],

Cell["The wave equation", "Text"],

Cell[BoxData[
    \(\[PartialD]\_\(t\ t\)\[Rho][x, t] - 
        \(v\^2\) \[PartialD]\_\(x\ x\)\[Rho][x, t] = 0\)], "NumberedEquation",\

  CellTags->"Wellen-Gleichung"],

Cell["\<\
also owns a time dependent variance of the static propagator:\
\>", "Text"],

Cell[BoxData[
    \(\[Rho][x, t] = 
      \(\((\(\[Delta][x - v\ t] + \[Delta][x + v\ t]\)\/2)\)\ .\)\)], 
  "NumberedEquation",
  CellTags->"Wellen-L\[ODoubleDot]sung"],

Cell["The mean scatter square increases clearly by time square:", "Text"],

Cell[BoxData[
    \(\[Sigma]\^2 = \(v\^2\) \(t\^2\ .\)\)], "NumberedEquation",
  CellTags->"Wellen-Varianz"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Classification Scheme of Diffusive Processes"
}], "Subsubsection"],

Cell[TextData[{
  "Normal diffusion stands out for proportionality of the static propagator \
variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\^2\)]],
  " to the measuring time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " (Einstein's relation)\[LongDash]independently of the shape of the initial \
value problems and of the existence of a maximum expansion velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  "."
}], "Text"],

Cell[TextData[{
  "A general diffusive process stands out for a stricly monotonously \
increasing variance of the static propagator, where the growth is described \
by a power law in time (",
  ButtonBox["[WGMN1997]",
    ButtonData:>{"Literatur.nb", "[WGMN1997]"},
    ButtonStyle->"Hyperlink"],
  ", section ",
  StyleBox["V",
    FontWeight->"Bold"],
  ", pages 103-104; ",
  ButtonBox["[ZSKN1999]",
    ButtonData:>{"Literatur.nb", "[ZSKN1999]"},
    ButtonStyle->"Hyperlink"],
  ", section ",
  StyleBox["I",
    FontWeight->"Bold"],
  ", page 1292):"
}], "Text"],

Cell[BoxData[
    \(\(\(\[Sigma]\^2\)~\(t\^\(\ \[Alpha]\)\)\ .\)\)], "NumberedEquation",
  CellTags->"Diffusionsvarianz"],

Cell[TextData[{
  "The power ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " of the diffusion variance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Diffusionsvarianz"],
  ") enables the following classification, which shall be valid furthermore:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Alpha] < 1\)]],
  ":\tanomalously slow diffusion (subdiffusion),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1\)]],
  ":\t\tnormal diffusion (Einstein's relation),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`1 < \[Alpha] < 2\)]],
  ":\tanomalously rapid diffusion (superdiffusion),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 2\)]],
  ":\t\tballististic transport (wave expansion),"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 2\)]],
  ":\t\tturbulent transport."
}], "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "To get the power ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", the variance balance is drawn double logarithmic as straight line, this \
is ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[CapitalDelta]\[Sigma]\^2 = 
        \(\[Sigma]\^2\)[t] - \(\[Sigma]\^2\)[t\_0]\)]],
  " over ",
  Cell[BoxData[
      \(TraditionalForm\`t - t\_0\)]],
  ". Especially, if the variance balance (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianzabgleich"],
  ") is missing, such kinds of double logarithmic figures cause fallacies. \
The gradient ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " of the resulting straight line in non-distorted representation \
corresponds to the power ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`t\^\[Alpha]\)]],
  "."
}], "Text"],

Cell["\<\
All processes, the propagator variances of which cannot be described by a \
power law in time, or which even do not increase strictly monotonously, are \
not to be considered as diffusive processes. Among these for example is the \
car distribution in Ulm, or the distribution of ants in and around an \
anthill.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Further Aspects of Diffusion Description"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". How to Deal with Drift in Dynamics"
}], "Subsubsection"],

Cell[TextData[{
  "It is controversial, whether for diffusion description also a temporal \
change of the expectation value of the distribution function is allowed. \
Certainly, this kind of considerations both will not change anything of \
variance, and it prevents a radial symmetric generalization from one space \
dimension to several space dimensions, because this generalization at \
presence of drift leads to sources and hollows of the transported material \
and thus contradicts to the originally set continuity equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Kontinuit\[ADoubleDot]tsgleichung"],
  ")."
}], "Text"],

Cell[TextData[{
  "The discussion of drift terms, how there is popularity especially as part \
of the Fokker Planck equations (",
  ButtonBox["[Ris1984]",
    ButtonData:>{"Literatur.nb", "[Ris1984]"},
    ButtonStyle->"Hyperlink"],
  ", section 1.2.1, page 4-5; ",
  ButtonBox["[vKam1984]",
    ButtonData:>{"Literatur.nb", "[vKam1984]"},
    ButtonStyle->"Hyperlink"],
  ", chapter X.3, pages 291-293), therefore is not the main focus of the \
elaboration presented here."
}], "Text"],

Cell[TextData[{
  "Rather, as part of this elaboration the ",
  StyleBox["gravity center theorem",
    FontSlant->"Italic"],
  " is set to be given and also to be aspired to the experiment. Certainly, \
drift can change the shape of a distribution function temporally, while the \
variance should be independent thereof."
}], "Text"],

Cell["\<\
Now, to enable comparison of two different theories with each identical \
variance behaviour to measured data, the missing of a drift (temporal change \
of the expectation value) is to be proven by measurement at the experimental \
set-up, before one of both theories can be prefered.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Generalization to Several Space Dimensions"
}], "Subsubsection"],

Cell[TextData[{
  "Due to Rayleigh (",
  ButtonBox["[Fel1971]",
    ButtonData:>{"Literatur.nb", "[Fel1971]"},
    ButtonStyle->"Hyperlink"],
  ", section I.10(e), pages 32-33), an isotropic (independent of direction) \
dynamics clearly can be projected to a single space dimension."
}], "Text"],

Cell[TextData[{
  "The oldest example for this kind of description comes from L. Euler when \
discussing the three-dimensional wave equation in comparison to the \
one-dimensional one (",
  ButtonBox["[HT1956]",
    ButtonData:>{"Literatur.nb", "[HT1956]"},
    ButtonStyle->"Hyperlink"],
  ", equations (26)-(30), page 421 and page 465)."
}], "Text",
  PageBreakAbove->True],

Cell[TextData[{
  "In this case, the corresponding Laplace operator changes according to the \
transformation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi][r, t] = P[r, \ t]\/f[r]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`f[r]\)]],
  " gives the corresponding distance law, so in case of a spherical wave ",
  Cell[BoxData[
      \(TraditionalForm\`f[r] = \@\(4  \[Pi]\ r\^2\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[PartialD]\^2 P[r, t]\/\[PartialD]r\^2 \[LeftRightArrow] 
      \(\((\(1\/f[r]\) 
            \[PartialD]\^2\((f[r]\ \[Phi][r, t])\)\/\[PartialD]r\^2)\)\ .
        \)\)], "NumberedEquation",
  CellTags->"Eulerscher Trick"],

Cell["\<\
This way, radial symmetric, linear equations with complicated, analytical \
coefficients clearly turn to simple linear equations in one space dimension \
only.\
\>", "Text"],

Cell[TextData[{
  "With two space dimensions or with distance laws of diffusion, Euler's \
trick (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Eulerscher Trick"],
  ") is not use, because from deductive mathematics follow different results \
(for example ",
  ButtonBox["[Metz1996]",
    ButtonData:>{"Literatur.nb", "[Metz1996]"},
    ButtonStyle->"Hyperlink"],
  ", equation (6.4), page 74), which prevent the turn to a one-dimensional \
equation."
}], "Text"],

Cell["\<\
The specific distance law for the dynamics on a spherical surface for example \
yields\
\>", "Text"],

Cell[BoxData[
    \(\(f[r] = 2  \[Pi]\ R\  | Sin[r\/R] | \ , \)\)], "NumberedEquation",
  CellTags->"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " describes the arc distance on the spherical surface, and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " the radius of the sphere. The corresponding Laplace operator for wave or \
diffusion has not yet been derived on an independent way until now."
}], "Text"],

Cell["\<\
An essential difference between a wave and diffusion in several dimensions \
consists in the fact, that for diffusion the spatial integral over the \
density is a conservation quantity (often the total mass), while for a wave \
the spatial integral over the square of the wave solution is a conservation \
quantity (usually the total energy). This difference does not attract \
attention for the one-dimensional consideration.\
\>", "Text"],

Cell[TextData[{
  "In order not to be out of proportion of this elaboration, during the \
further course discussions mainly are done in a single space dimension only, \
which can be transfered to radial symmetric problems at least by use of \
Euler's trick (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Eulerscher Trick"],
  ")."
}], "Text"],

Cell[TextData[{
  "The combination of the distance law (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", 
  "Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"],
  ") with Euler's trick (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Eulerscher Trick"],
  ") can be discussed as part of an own hypothetical model, while other \
generalizations of the Laplace operator also own other solutions as part of \
other models."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Description of Anomalous Diffusion"
}], "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". The Formula by Wei, Bechinger, and Leiderer"
}], "Subsection"],

Cell[TextData[{
  "In their paper ",
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  " Wei Q.-H., C. Bechinger, and P. Leiderer give a normal distribution with \
a variance describing anomalous diffusion. This distribution reads (",
  ButtonBox["[WBL2000]",
    ButtonData:>{"Literatur.nb", "[WBL2000]"},
    ButtonStyle->"Hyperlink"],
  ", equation (2), page 627):"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x, t] = 
      \(\((Exp[\(-\(x\^2\/\(4  F\ t\^\[Alpha]\)\)\)]
              \/\@\(4  \[Pi]\ F\ t\^\[Alpha]\))\)\ .\)\)], "NumberedEquation",\

  CellTags->"Wei-Formel"],

Cell[TextData[{
  "In the mentioned paper also further sources are cited for this \
distribution, but not on the basis of a dynamic equation. Rather this \
approach is purely heuristic, by which at least the phenomenon ",
  StyleBox["anomalous diffusion",
    FontSlant->"Italic"],
  " is described correctly concerning variance."
}], "Text"],

Cell["\<\
The authors of this paper kindly put their measured data for further \
evaluation at the author's disposal as part of this elaboration.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Time Fractional Diffusion Equations"
}], "Subsection"],

Cell[TextData[{
  "In their paper ",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  " Schneider and Wyss give a modified Fickian diffusion equation, which uses \
Riemann's integral operator and also describes anomalous diffusion."
}], "Text"],

Cell[TextData[{
  "Riemann's integral operator interpolates the several orders of integration \
and differentiation. It is defined sensibly for all complex differential \
orders ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  ". In the software package ",
  StyleBox["FractionalCalculus",
    FontSlant->"Italic"],
  " just the differential operator of Riemann and Liouville is available (",
  ButtonBox["[SKM1993]",
    ButtonData:>{"Literatur.nb", "[SKM1993]"},
    ButtonStyle->"Hyperlink"],
  ", equation (2.32), page 37), which for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  " turns to Riemann's integral operator of the integration order ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Beta]\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
    \(\[ScriptCapitalD]\_\(a, \ x\)\%\[Beta][f[x]] := 
        \(\((\[DifferentialD]\/\[DifferentialD]x)\)\^\[Eta]\) 
          \(1\/\[CapitalGamma][\[Eta] - \[Beta]]\) 
          \(\[Integral]\_a\%x\( f[y]\/\((x - y)\)\^\(\[Beta] - \[Eta] + 1\)\) 
              \[DifferentialD]y\)\), " ", ",", "\n", "\n", 
      RowBox[{"\[Eta]", "=", 
        RowBox[{"{", GridBox[{
             
               {\(\([\ Re[\[Beta]]\ ]\) + 1\ \ \ \ \ \ \ \ \ \ Re[\[Beta]] 
                  \[GreaterEqual] 0\ , \)},
             
               {\(\ \ \ \ \ \ \ \ \ \ \ \ \ 
                0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Re[\[Beta]] < 
                  \(0\ .\)\)}
              }]}]}]}]], "NumberedEquation",
  CellTags->"Riemann-Liouville-Operator"],

Cell[TextData[{
  "The Riemann Liouville operator in purely integral representation (",
  Cell[BoxData[
      \(TraditionalForm\`Re[\[Beta]] < 0\)]],
  ") at ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0\)]],
  " gives a Laplace convolution with a power function. The physical \
motivation of the Riemann Liouville operator is discussed time and again. A \
possible access is indicated in section 3.1.1 of this elaboration."
}], "Text"],

Cell[TextData[{
  "Since the Laplace transformation of a linear equation yields the initial \
value problems, there are all kinds of analytical difficulties to set up a \
time fractional equation with consistent initial value problem. This kind of \
problems have already been dealed with successfully by the work of Schneider \
and Wyss (",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  ", equation (1.1)-(1.5), page 134), Gloeckle (",
  ButtonBox["[Gloe1993]",
    ButtonData:>{"Literatur.nb", "[Gloe1993]"},
    ButtonStyle->"Hyperlink"],
  ", section 3.3, page 28-33), and finally Wyss and Wyss ",
  ButtonBox["[WW1999]",
    ButtonData:>{"Literatur.nb", "[WW1999]"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  PageBreakAbove->True],

Cell[TextData[{
  "The addition of an inhomogenous stearing force ",
  Cell[BoxData[
      \(TraditionalForm\`\(s[x, t]\ \)\)]],
  " to the equation by Schneider Wyss yields the following representation of \
the time fractional diffusion equation with ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Beta] \[LessEqual] 1\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\[Rho]\_t[x, t] - 
        \[Lambda]\ 
          \[ScriptCapitalD]\_\(0, \ t\)\%\(1 - \[Beta]\)[
            \[Rho]\_\(x\ x\)[x, t]] = \(s[x, t]\ .\)\)], "NumberedEquation",
  CellTags->"zeit-fraktionale Diffusionsgleichung"],

Cell[TextData[{
  "The integrated representation of this equation contains all initial value \
problems and does not cause any problems also concerning Laplace \
transformation, here because of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] > 0\)]],
  " (see ",
  ButtonBox["[SWy1989]",
    ButtonData:>{"Literatur.nb", "[SWy1989]"},
    ButtonStyle->"Hyperlink"],
  ", equation (2.1), page 135):"
}], "Text"],

Cell[BoxData[
    \(\[Rho][x, t] - 
        \[Sum]\+\(n = 0\)\%\(\(-1\) - 
              \([\(-\[Beta]\)]
                \)\)\(\[PartialD]\^n \[Rho][x, t \[Rule] 0]\/\[PartialD]x\^n
                    \) t\^n\/\(n!\)\  - \ 
        \[Lambda]\ 
          \[ScriptCapitalD]\_\(0, \ t\)\%\(-\[Beta]\)[
            \[PartialD]\^2 \[Rho][x, t]\/\[PartialD]x\^2] = 
      \(\[ScriptCapitalD]\_\(0, \ t\)\%\(\(-1\) - \([\(-\[Beta]\)]\)\)[
          s[x, t]]\ .\)\)], "NumberedEquation",
  CellTags->"inhomogene Schneider-Wyss-Gleichung"],

Cell[TextData[{
  "In this connection has been used, that Riemann's integral operator is a \
generalization of Cauchy's iterated integral (",
  ButtonBox["[Non1996]",
    ButtonData:>{"Literatur.nb", "[Non1996]"},
    ButtonStyle->"Hyperlink"],
  ", chapter 2.2.2, page 19). The Gaussian step function (",
  ButtonBox["[Wol1997]",
    ButtonData:>{"Literatur.nb", "[Wol1997]"},
    ButtonStyle->"Hyperlink"],
  ", chapter 3.2.2, function ",
  Cell[BoxData[
      \(TraditionalForm\`Floor[\ ]\)]],
  ", page 775) or Gaussian bracket function is marked by angle brackets ",
  Cell[BoxData[
      \(TraditionalForm\`\([\ ]\)\)]],
  ", without a leading symbol."
}], "Text"],

Cell[TextData[{
  "Both representations (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "zeit-fraktionale Diffusionsgleichung"],
  ") and (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "inhomogene Schneider-Wyss-Gleichung"],
  ") of the time fractional diffusion equation interpolate between Fick's \
diffusion equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  ") and the wave equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Wellen-Gleichung"],
  ") in a single space dimension. Therefore the variance of the propagator of \
equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "inhomogene Schneider-Wyss-Gleichung"],
  ") also clearly yields a temporal power law ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Sigma]\^2\)~\(t\^\[Beta]\)\)]],
  " to describe anomalous diffusion, what will be shown more detailed as part \
of this elaboration (chapter 3) and on the basis of measured examples \
(chapter 4 and 5)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Space Fractional Diffusion Equations"
}], "Subsection"],

Cell[TextData[{
  "In their paper West et al. ",
  ButtonBox["[WGMN1997]",
    ButtonData:>{"Literatur.nb", "[WGMN1997]"},
    ButtonStyle->"Hyperlink"],
  " use the symmetric Riesz operator to discuss a fraction numbered order of \
differentiation instead of the Laplace operator in Fick's diffusion equation \
(",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  "). This causes solution functions with L\[EAcute]vy asymptotics, which \
also seem to describe anomalous diffusion."
}], "Text"],

Cell["\<\
The Riesz operator is introduced in section 2.3.2.6 of this elaboration \
within its mathematical context.\
\>", "Text",
  PageBreakBelow->True],

Cell[TextData[{
  "The problem with L\[EAcute]vy distributed results is, that the variance, \
being calculated theoretically by this, diverges for use of infinite \
integration limits. Therefore, these integration limits of the momentum \
integrals are to be co-ordinated to the dimensions of the experiment to apply \
the variance theorem (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Varianztheorem"],
  ") when comparing theory to measured data."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Space and Time Fractional Diffusion Equations"
}], "Subsection"],

Cell["\<\
A combination of space and time fractional diffusion equations can take place \
because of didactic reasons to do the analytical calculation once only and to \
yield a result as general as possible.\
\>", "Text"],

Cell[TextData[{
  "Concerning the classification of diffusive behaviour via the variance, \
this approach for the first time seems to own to much parameters, what can be \
used to join further examinations on theory. By this, the understanding of \
the inhomogenously added equation by Schneider and Wyss (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "inhomogene Schneider-Wyss-Gleichung"],
  ") can be deepened."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Summary"
}], "Section"],

Cell[TextData[{
  "Independently, whether a diffusion equation is parabolic (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "2.Ficksches Gesetz"],
  "), elliptic (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "modifizierte Cattaneo-Gleichung"],
  "), or discrete (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Differenzengleichung"],
  "), for the variance of the propagator results at least the hypothesis of \
the proportionality to time, this is normal diffusion in the sense of \
Einstein's relation. The hyperbolic Cattaneo equation (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Cattaneo-Gleichung"],
  ") for diffusion only asymptotically for long times owns the variance of \
normal diffusion."
}], "Text"],

Cell["\<\
All diffusion equations are linear equations, what is following from the \
superposition principle.\
\>", "Text"],

Cell["\<\
For assessment of diffusive processes, in first priority serves the variance \
in its temporal behaviour, being balanced to the start variance. This kind of \
experimental evaluation can be compared directly to the variance of the \
theoretical derived propagator.\
\>", "Text"],

Cell[TextData[{
  "Diffusive processes own a variance increasing strictly monotonously with \
time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". The variance of the diffusion propagator satisfies a power law in time."
}], "Text"],

Cell["\<\
To model anomalous diffusion, most easily fractionalized Fick's diffusion \
equations can be used, which is the focal point of this elaboration in its \
further course.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 742}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1248, 719},
WindowMargins->{{-4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingStartingPageNumber->15,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Chapter 1. Description of Diffusion"}], "Header"]}, {
    Cell[ 
        TextData[ {"Chapter 1. Description of Diffusion"}], "Header"], 
      Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Kontinuit\[ADoubleDot]tsgleichung"->{
    Cell[2779, 108, 160, 3, 32, "NumberedEquation",
      CellTags->"Kontinuit\[ADoubleDot]tsgleichung"]},
  "1.Ficksches Gesetz"->{
    Cell[3659, 138, 140, 3, 32, "NumberedEquation",
      CellTags->"1.Ficksches Gesetz"]},
  "2.Ficksches Gesetz"->{
    Cell[4993, 177, 180, 4, 32, "NumberedEquation",
      CellTags->"2.Ficksches Gesetz"]},
  "Fickscher Diffusionspropagator"->{
    Cell[6666, 233, 209, 4, 66, "NumberedEquation",
      CellTags->"Fickscher Diffusionspropagator"]},
  "Normalverteilung"->{
    Cell[8129, 283, 199, 4, 68, "NumberedEquation",
      CellTags->"Normalverteilung"]},
  "Cattaneo-Gleichung"->{
    Cell[9644, 337, 233, 5, 32, "NumberedEquation",
      CellTags->"Cattaneo-Gleichung"]},
  "Diffusionskonstante"->{
    Cell[10506, 364, 110, 2, 33, "NumberedEquation",
      CellTags->"Diffusionskonstante"]},
  "Varianz der Cattaneo-Gleichung"->{
    Cell[12009, 412, 193, 4, 33, "NumberedEquation",
      CellTags->"Varianz der Cattaneo-Gleichung"]},
  "Differenzengleichung"->{
    Cell[18311, 618, 233, 4, 47, "NumberedEquation",
      CellTags->"Differenzengleichung"]},
  "Binomialverteilung"->{
    Cell[20400, 684, 759, 16, 60, "NumberedEquation",
      CellTags->"Binomialverteilung"]},
  "Varianz der Binomialverteilung"->{
    Cell[22547, 745, 292, 6, 47, "NumberedEquation",
      CellTags->"Varianz der Binomialverteilung"]},
  "modifizierte Cattaneo-Gleichung"->{
    Cell[23942, 795, 287, 5, 50, "NumberedEquation",
      CellTags->"modifizierte Cattaneo-Gleichung"]},
  "Binomialer Grenz\[UDoubleDot]bergang"->{
    Cell[26895, 899, 780, 17, 92, "NumberedEquation",
      CellTags->"Binomialer Grenz\[UDoubleDot]bergang"]},
  "Varianztheorem"->{
    Cell[33379, 1113, 317, 8, 73, "NumberedEquation",
      CellTags->"Varianztheorem"]},
  "Delta-Faltung"->{
    Cell[34166, 1135, 179, 3, 48, "NumberedEquation",
      CellTags->"Delta-Faltung"]},
  "Varianzabgleich"->{
    Cell[34706, 1154, 216, 4, 33, "NumberedEquation",
      CellTags->"Varianzabgleich"]},
  "Wellen-Gleichung"->{
    Cell[38512, 1293, 169, 4, 33, "NumberedEquation",
      CellTags->"Wellen-Gleichung"]},
  "Wellen-L\[ODoubleDot]sung"->{
    Cell[38772, 1303, 169, 4, 47, "NumberedEquation",
      CellTags->"Wellen-L\[ODoubleDot]sung"]},
  "Wellen-Varianz"->{
    Cell[39020, 1311, 108, 2, 33, "NumberedEquation",
      CellTags->"Wellen-Varianz"]},
  "Diffusionsvarianz"->{
    Cell[40414, 1364, 121, 2, 33, "NumberedEquation",
      CellTags->"Diffusionsvarianz"]},
  "Eulerscher Trick"->{
    Cell[46412, 1572, 243, 5, 53, "NumberedEquation",
      CellTags->"Eulerscher Trick"]},
  "Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"->{
    Cell[47444, 1605, 149, 2, 44, "NumberedEquation",
      CellTags->"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"]},
  "Wei-Formel"->{
    Cell[50081, 1692, 195, 5, 66, "NumberedEquation",
      CellTags->"Wei-Formel"]},
  "Riemann-Liouville-Operator"->{
    Cell[52042, 1756, 780, 17, 120, "NumberedEquation",
      CellTags->"Riemann-Liouville-Operator"]},
  "zeit-fraktionale Diffusionsgleichung"->{
    Cell[54422, 1819, 245, 5, 36, "NumberedEquation",
      CellTags->"zeit-fraktionale Diffusionsgleichung"]},
  "inhomogene Schneider-Wyss-Gleichung"->{
    Cell[55087, 1839, 532, 11, 63, "NumberedEquation",
      CellTags->"inhomogene Schneider-Wyss-Gleichung"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Kontinuit\[ADoubleDot]tsgleichung", 63266, 2088},
  {"1.Ficksches Gesetz", 63399, 2091},
  {"2.Ficksches Gesetz", 63517, 2094},
  {"Fickscher Diffusionspropagator", 63647, 2097},
  {"Normalverteilung", 63775, 2100},
  {"Cattaneo-Gleichung", 63891, 2103},
  {"Diffusionskonstante", 64010, 2106},
  {"Varianz der Cattaneo-Gleichung", 64142, 2109},
  {"Differenzengleichung", 64275, 2112},
  {"Binomialverteilung", 64396, 2115},
  {"Varianz der Binomialverteilung", 64528, 2118},
  {"modifizierte Cattaneo-Gleichung", 64672, 2121},
  {"Binomialer Grenz\[UDoubleDot]bergang", 64822, 2124},
  {"Varianztheorem", 64956, 2127},
  {"Delta-Faltung", 65067, 2130},
  {"Varianzabgleich", 65179, 2133},
  {"Wellen-Gleichung", 65294, 2136},
  {"Wellen-L\[ODoubleDot]sung", 65419, 2139},
  {"Wellen-Varianz", 65542, 2142},
  {"Diffusionsvarianz", 65657, 2145},
  {"Eulerscher Trick", 65774, 2148},
  {"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che", 65920, 2151},
  {"Wei-Formel", 66060, 2154},
  {"Riemann-Liouville-Operator", 66180, 2157},
  {"zeit-fraktionale Diffusionsgleichung", 66328, 2160},
  {"inhomogene Schneider-Wyss-Gleichung", 66483, 2163}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 29, 0, 69, "Subtitle"],

Cell[CellGroupData[{
Cell[1763, 53, 41, 0, 109, "Title"],

Cell[CellGroupData[{
Cell[1829, 57, 123, 5, 68, "Section"],

Cell[CellGroupData[{
Cell[1977, 66, 144, 7, 64, "Subsection"],
Cell[2124, 75, 206, 4, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2367, 84, 146, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[2538, 95, 182, 9, 51, "Subsubsection"],
Cell[2723, 106, 53, 0, 32, "Text"],
Cell[2779, 108, 160, 3, 32, "NumberedEquation",
  CellTags->"Kontinuit\[ADoubleDot]tsgleichung"],
Cell[2942, 113, 469, 15, 72, "Text"],
Cell[3414, 130, 242, 6, 32, "Text"],
Cell[3659, 138, 140, 3, 32, "NumberedEquation",
  CellTags->"1.Ficksches Gesetz"],
Cell[3802, 143, 677, 16, 92, "Text",
  PageBreakBelow->True],
Cell[4482, 161, 508, 14, 72, "Text"],
Cell[4993, 177, 180, 4, 32, "NumberedEquation",
  CellTags->"2.Ficksches Gesetz"],
Cell[5176, 183, 913, 25, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6126, 213, 201, 9, 51, "Subsubsection"],
Cell[6330, 224, 333, 7, 52, "Text"],
Cell[6666, 233, 209, 4, 66, "NumberedEquation",
  CellTags->"Fickscher Diffusionspropagator"],
Cell[6878, 239, 276, 8, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7191, 252, 214, 9, 51, "Subsubsection"],
Cell[7408, 263, 718, 18, 92, "Text"],
Cell[8129, 283, 199, 4, 68, "NumberedEquation",
  CellTags->"Normalverteilung"],
Cell[8331, 289, 479, 14, 52, "Text"],
Cell[8813, 305, 148, 3, 52, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9010, 314, 186, 8, 64, "Subsection",
  PageBreakAbove->True],
Cell[9199, 324, 442, 11, 52, "Text"],
Cell[9644, 337, 233, 5, 32, "NumberedEquation",
  CellTags->"Cattaneo-Gleichung"],
Cell[9880, 344, 623, 18, 72, "Text"],
Cell[10506, 364, 110, 2, 33, "NumberedEquation",
  CellTags->"Diffusionskonstante"],
Cell[10619, 368, 231, 6, 52, "Text"],
Cell[10853, 376, 519, 15, 52, "Text"],
Cell[11375, 393, 631, 17, 72, "Text"],
Cell[12009, 412, 193, 4, 33, "NumberedEquation",
  CellTags->"Varianz der Cattaneo-Gleichung"],
Cell[12205, 418, 881, 24, 116, "Text",
  PageBreakBelow->True],
Cell[13089, 444, 680, 21, 76, "Text"],
Cell[13772, 467, 633, 16, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14442, 488, 173, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[14640, 499, 212, 9, 51, "Subsubsection"],
Cell[14855, 510, 371, 10, 53, "Text"],
Cell[15229, 522, 384, 8, 92, "Text"],
Cell[15616, 532, 169, 3, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15822, 540, 220, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[16045, 552, 444, 9, 72, "Text"],
Cell[16492, 563, 971, 23, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17500, 591, 190, 9, 51, "Subsubsection"],
Cell[17693, 602, 615, 14, 92, "Text"],
Cell[18311, 618, 233, 4, 47, "NumberedEquation",
  CellTags->"Differenzengleichung"],
Cell[18547, 624, 425, 8, 92, "Text"],
Cell[18975, 634, 542, 13, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19554, 652, 230, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[19787, 664, 610, 18, 72, "Text"],
Cell[20400, 684, 759, 16, 60, "NumberedEquation",
  CellTags->"Binomialverteilung"],
Cell[21162, 702, 478, 14, 56, "Text"],
Cell[21643, 718, 901, 25, 114, "Text"],
Cell[22547, 745, 292, 6, 47, "NumberedEquation",
  CellTags->"Varianz der Binomialverteilung"],
Cell[22842, 753, 269, 9, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23148, 767, 232, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[23383, 779, 556, 14, 72, "Text"],
Cell[23942, 795, 287, 5, 50, "NumberedEquation",
  CellTags->"modifizierte Cattaneo-Gleichung"],
Cell[24232, 802, 695, 18, 72, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24976, 826, 148, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[25149, 837, 218, 9, 51, "Subsubsection"],
Cell[25370, 848, 1202, 37, 92, "Text"],
Cell[26575, 887, 317, 10, 32, "Text"],
Cell[26895, 899, 780, 17, 92, "NumberedEquation",
  CellTags->"Binomialer Grenz\[UDoubleDot]bergang"],
Cell[27678, 918, 289, 7, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28004, 930, 217, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[28224, 942, 569, 18, 52, "Text"],
Cell[28796, 962, 1127, 27, 152, "Text"],
Cell[29926, 991, 929, 23, 112, "Text"],
Cell[30858, 1016, 412, 10, 72, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31331, 1033, 143, 6, 68, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[31499, 1043, 182, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[31706, 1054, 178, 9, 51, "Subsubsection"],
Cell[31887, 1065, 205, 4, 52, "Text"],
Cell[32095, 1071, 245, 4, 52, "Text"],
Cell[32343, 1077, 230, 4, 52, "Text"],
Cell[32576, 1083, 125, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32738, 1091, 187, 9, 51, "Subsubsection"],
Cell[32928, 1102, 448, 9, 92, "Text"],
Cell[33379, 1113, 317, 8, 73, "NumberedEquation",
  CellTags->"Varianztheorem"],
Cell[33699, 1123, 464, 10, 72, "Text"],
Cell[34166, 1135, 179, 3, 48, "NumberedEquation",
  CellTags->"Delta-Faltung"],
Cell[34348, 1140, 355, 12, 52, "Text",
  PageBreakAbove->True],
Cell[34706, 1154, 216, 4, 33, "NumberedEquation",
  CellTags->"Varianzabgleich"],
Cell[34925, 1160, 102, 3, 32, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35064, 1168, 205, 9, 51, "Subsubsection"],
Cell[35272, 1179, 293, 5, 72, "Text"],
Cell[35568, 1186, 340, 6, 72, "Text"],
Cell[35911, 1194, 452, 12, 72, "Text"],
Cell[36366, 1208, 122, 3, 32, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36537, 1217, 180, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[36742, 1228, 206, 9, 51, "Subsubsection"],
Cell[36951, 1239, 447, 11, 72, "Text"],
Cell[37401, 1252, 422, 11, 72, "Text"],
Cell[37826, 1265, 377, 9, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38240, 1279, 233, 10, 51, "Subsubsection",
  PageBreakAbove->True],
Cell[38476, 1291, 33, 0, 32, "Text"],
Cell[38512, 1293, 169, 4, 33, "NumberedEquation",
  CellTags->"Wellen-Gleichung"],
Cell[38684, 1299, 85, 2, 32, "Text"],
Cell[38772, 1303, 169, 4, 47, "NumberedEquation",
  CellTags->"Wellen-L\[ODoubleDot]sung"],
Cell[38944, 1309, 73, 0, 32, "Text"],
Cell[39020, 1311, 108, 2, 33, "NumberedEquation",
  CellTags->"Wellen-Varianz"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39165, 1318, 215, 9, 51, "Subsubsection"],
Cell[39383, 1329, 457, 13, 72, "Text"],
Cell[39843, 1344, 568, 18, 74, "Text"],
Cell[40414, 1364, 121, 2, 33, "NumberedEquation",
  CellTags->"Diffusionsvarianz"],
Cell[40538, 1368, 295, 9, 52, "Text"],
Cell[40836, 1379, 148, 5, 32, "Text"],
Cell[40987, 1386, 143, 5, 32, "Text"],
Cell[41133, 1393, 151, 5, 32, "Text"],
Cell[41287, 1400, 144, 5, 32, "Text"],
Cell[41434, 1407, 148, 6, 32, "Text",
  PageBreakBelow->True],
Cell[41585, 1415, 893, 29, 92, "Text"],
Cell[42481, 1446, 336, 6, 72, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42866, 1458, 170, 7, 64, "Subsection"],

Cell[CellGroupData[{
Cell[43061, 1469, 205, 9, 51, "Subsubsection"],
Cell[43269, 1480, 653, 12, 112, "Text"],
Cell[43925, 1494, 486, 12, 72, "Text"],
Cell[44414, 1508, 333, 7, 72, "Text"],
Cell[44750, 1517, 308, 5, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45095, 1527, 213, 9, 51, "Subsubsection"],
Cell[45311, 1538, 295, 7, 52, "Text"],
Cell[45609, 1547, 375, 9, 72, "Text",
  PageBreakAbove->True],
Cell[45987, 1558, 422, 12, 67, "Text"],
Cell[46412, 1572, 243, 5, 53, "NumberedEquation",
  CellTags->"Eulerscher Trick"],
Cell[46658, 1579, 183, 4, 52, "Text"],
Cell[46844, 1585, 484, 13, 72, "Text"],
Cell[47331, 1600, 110, 3, 32, "Text"],
Cell[47444, 1605, 149, 2, 44, "NumberedEquation",
  CellTags->"Abstandsgesetz auf Kugeloberfl\[ADoubleDot]che"],
Cell[47596, 1609, 347, 9, 72, "Text"],
Cell[47946, 1620, 450, 7, 92, "Text"],
Cell[48399, 1629, 363, 9, 72, "Text"],
Cell[48765, 1640, 466, 13, 72, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49292, 1660, 150, 6, 68, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[49467, 1670, 173, 7, 64, "Subsection"],
Cell[49643, 1679, 435, 11, 52, "Text"],
Cell[50081, 1692, 195, 5, 66, "NumberedEquation",
  CellTags->"Wei-Formel"],
Cell[50279, 1699, 342, 7, 72, "Text"],
Cell[50624, 1708, 159, 3, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50820, 1716, 165, 7, 64, "Subsection"],
Cell[50988, 1725, 300, 7, 52, "Text"],
Cell[51291, 1734, 748, 20, 92, "Text"],
Cell[52042, 1756, 780, 17, 120, "NumberedEquation",
  CellTags->"Riemann-Liouville-Operator"],
Cell[52825, 1775, 440, 10, 72, "Text"],
Cell[53268, 1787, 803, 19, 112, "Text",
  PageBreakAbove->True],
Cell[54074, 1808, 345, 9, 52, "Text"],
Cell[54422, 1819, 245, 5, 36, "NumberedEquation",
  CellTags->"zeit-fraktionale Diffusionsgleichung"],
Cell[54670, 1826, 414, 11, 72, "Text"],
Cell[55087, 1839, 532, 11, 63, "NumberedEquation",
  CellTags->"inhomogene Schneider-Wyss-Gleichung"],
Cell[55622, 1852, 670, 17, 72, "Text"],
Cell[56295, 1871, 1069, 29, 112, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57401, 1905, 166, 7, 64, "Subsection"],
Cell[57570, 1914, 533, 13, 72, "Text"],
Cell[58106, 1929, 154, 4, 32, "Text",
  PageBreakBelow->True],
Cell[58263, 1935, 483, 10, 92, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58783, 1950, 175, 7, 64, "Subsection"],
Cell[58961, 1959, 222, 4, 52, "Text"],
Cell[59186, 1965, 446, 9, 72, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[59681, 1980, 99, 5, 68, "Section"],
Cell[59783, 1987, 795, 21, 92, "Text"],
Cell[60581, 2010, 123, 3, 32, "Text"],
Cell[60707, 2015, 288, 5, 72, "Text"],
Cell[60998, 2022, 239, 6, 52, "Text"],
Cell[61240, 2030, 192, 4, 52, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

